<?php

// Id:

/**
 *  Allocate a course to a teacher. This process also creates a group for the course and teacher.
 * The teacher is the administrator of the group.
 *
 * This first page lists all teachers for a course, the nid of which is read from the URL
 *
 * @return array $form
 *
 */
function pe_course_add_teacher() {
  $nid = arg(1);
  $node = node_load($nid);

  $uids = array();
  $result = db_query("SELECT c.uid FROM {pe_course_list} c WHERE c.nid = %d", $nid);
  while($obj = db_fetch_object($result)) {
    $uids[] = $obj->uid;    
  }

  $sql = '';
  if(count($uids) > 0) {

    $_SESSION['users']['plus'] = $uids;

    $sql .= _get_basic_user_info_sql();
    $sql .= " AND u1.uid IN (". implode(", ", $uids) .") \n";
  }
  // 
  $gid = _get_og_by_name(variable_get('acad_staff_group', 'Teachers'), $type = NODE_TYPE_GROUP);
  $teachers = _get_og_uids(array($gid));
  if(count($teachers) > 0) {
    $_SESSION['users']['plus'] = $teachers;
  }

  $header = array(
    array('data' => t('#')),
    array('data' => t('Name'), 'field' => 'field_lastname', 'sort' => 'asc'),
    array('data' => t('Gender'), 'field' => 'field_gender'),
  );

  $args = $rows = array();
  if(drupal_strlen($sql)) {
    $show_count = variable_get('items_per_page', 100);
    $tablesort = tablesort_sql($header);
    $rst = pager_query($sql . $tablesort, $show_count, 0, NULL, $args);

    $i = 0;
    while($row = db_fetch_object($rst)) {
      // mock up user profile
      $account = new stdClass();
      $account->uid = $row->uid;
      $account->name = $row->name;
      $account->profile->field_lastname[0]['value'] = $row->field_lastname;
      $account->profile->field_firstname[0]['value'] = $row->field_firstname;
      $account->profile->field_personal_title[0]['value'] = _translate_personal_title($row->field_personal_title);

      $rows[] = array(
        array('data' => $i + 1, 'align' => 'center'),
        array('data' => theme('username', $account, $link = 1, $access = 1, $path, $attributes)),
        array('data' => ($row->field_gender != '') ? theme('image', "misc/icon_" . drupal_strtolower($row->field_gender) . ".gif")  : '--', 'align' => 'center')
      );
      $i++;
    }
  }
  if (count($rows) < 1) {
    $rows[] = array(array('data' => t('No teachers for this course yet.'), 'colspan' => count($header), 'align' => 'center'));
  }
  // group title, group type
  $og = _get_nid_from_title(variable_get('acad_staff_group', 'Teachers'), variable_get('basic_group', 'pe_group'));

  $output = '';
  $output .= '<p>'. t('Add a new teacher for this course. A course group will also be automatically created for this teacher.') .'</p>';
  $output .= drupal_get_form('pe_user_autocomplete_form', $og, $node);
  $output .= theme('table', $header, $rows);
  $output .= theme('pager', NULL, $show_count, 0);
  return $output;
}


/**
 * Form for the autocompletion of teachers' full names when allocating a course.
 *
 * @param array $form_state
 *  parameters passed from the current state of the form
 * @param obect $node
 *  the course node
 * @return array $form
 * the form definition with the hidden in the "value" field
 *
 */
function pe_user_autocomplete_form(&$form_state, $node) {
  $form['node'] = array(
    '#type' => 'value',
    '#value'  => $node,
  );

  $form['uid'] = array(
    '#type' => 'textfield',
    '#autocomplete_path' => 'pe_user/autocomplete',
    '#size' => '30',
    '#prefix' => '<div class="container-inline">',
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Find a teacher'),
    '#suffix' => '</div>',
  );

  return $form;
}


/**
 * Autocomplete function for teachers' full names when the form is submitted. Also this is where
 * some validation of the form is done.
 *
 * @param array $form
 * @param array $form_state
 *
 */
function pe_user_autocomplete_form_submit($form, &$form_state) {
  $values = $form_state['values'];
  $course = $values['node'];
  
  $uid = $values['uid'];
  $values['uid'] = trim(substr($uid, strripos($uid, '-')+1));

  if($values['uid'] < 1) {
    form_set_error('uid', t('A valid user is required.'));
    $error = 1;
  }
  else {
    // update acad staff course list
    $rst = db_query("INSERT INTO {pe_course_list} (uid, nid) VALUES(%d, %d)", $values['uid'], $course->nid);
    if(!$rst) {
      $error = 1;
      $msg = t('Could not initiate creation of new course group. No teacher-course assocation made.');
    }
    else {
      // create course group node managed by acad staff
      $edit = array();

      $course_title = $course->title;
      $course_title .= (drupal_strlen($course->field_code[0]['value'])) ? ' - '. $course->field_code[0]['value'] : '';
      $course_title .= ' - '. $values['uid'];

      $edit['title'] = $course_title;
      $edit['body'] = t('Course group for teaching !course', array('!course' => $course->title));
      $edit['uid'] = $values['uid'];
      $edit['name'] = _get_name_from_uid($values['uid']);
      $edit['type'] = variable_get('course_group', 'pe_group_course');
      $edit['created'] = time();
      $edit['changed'] = time() + 5000;
      $edit['comment'] = 0;
      $edit['sticky'] = 0;
      $edit['promoted'] = 0;
      $edit['taxonomy'] = array();
      // cck field
      $edit['field_course_id'][0]['nid'] = $course->nid;
      // og fields
      $edit['og_description'] = t('Course group : %code', array('%code' => $course->field_code[0]['value']));
      $edit['og_selective'] = OG_CLOSED;
      $edit['og_directory'] = OG_DIRECTORY_ALWAYS;

      $node = (object)$edit;
      $node = node_submit($node);
      node_save($node);
      content_insert($node);

      if($node->nid > 0) {
        $msg = t('New course group created.');
      }
      else {
        $error = 1;
        $msg = t('Could not create the course group.');
      }
    }
  }
  $type = ($error) ? 'error' : '';
  drupal_set_message($msg, $type);
}
